==> tasks-v1.8.8.zip: tasks/messages/th/base.php <==
<?php

return [
    '1 Day before' => '1 วันก่อน',
    '1 Month before' => '1 เดือนก่อน',
    '1 Week before' => '1 สัปดาห์ก่อน',
    '2 Days before' => '2 วันก่อน',
    '2 Weeks before' => '2 สัปดาห์ก่อน',
    '3 Weeks before' => '3 สัปดาห์ก่อน',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>ผู้ใช้ที่ได้รับมอบหมาย</strong> ได้รับอนุญาตให้ดำเนินการงานนี้',
    '<strong>Confirm</strong> task deletion' => '<strong>ยืนยัน</strong> การลบงาน',
    '<strong>Create</strong> task list' => '<strong>สร้าง</strong> รายการงาน',
    '<strong>Edit</strong> task' => '<strong>แก้ไข</strong> งาน',
    '<strong>Edit</strong> task list' => '<strong>แก้ไข</strong> รายการงาน',
    '<strong>Task</strong> Overview' => '<strong>งาน</strong> ภาพรวม',
    '<strong>Your</strong> tasks' => 'งาน <strong>ของคุณ</strong>',
    'Accept Task' => 'รับงาน',
    'Add Deadline to space calendar' => 'เพิ่มกำหนดเวลาในปฏิทินอวกาศ',
    'Add checkpoint...' => 'เพิ่มด่าน...',
    'Add reminder' => 'เพิ่มการเตือนความจำ',
    'Add responsible users' => 'เพิ่มผู้ใช้ที่รับผิดชอบ',
    'Add schedule to the space calendar' => 'เพิ่มกำหนดการในปฏิทินอวกาศ',
    'Add task' => 'เพิ่มงาน',
    'Add to space calendar' => 'เพิ่มในปฏิทินอวกาศ',
    'All Day' => 'ทั้งวัน',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'อนุญาตให้ผู้ใช้สร้างงานใหม่ ผู้ใช้จะสามารถแก้ไขและลบงานของตัวเองเท่านั้น',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'อนุญาตให้ผู้ใช้สร้าง ลบ และแก้ไขงานและรายการ และยังจัดเรียงงานและรายการ',
    'Allows the user to process unassigned tasks' => 'อนุญาตให้ผู้ใช้ประมวลผลงานที่ยังไม่ได้มอบหมาย',
    'Already requested' => 'ร้องขอแล้ว',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'ผู้ใช้ที่มีสิทธิ์ "ประมวลผลงานที่ยังไม่ได้มอบหมาย" สามารถทำงานในงานนี้ได้',
    'Anyone can work on this task!' => 'งานนี้ใครๆ ก็ทำได้',
    'Assign users' => 'กำหนดผู้ใช้',
    'Assigned' => 'ที่ได้รับมอบหมาย',
    'Assignment' => 'งานที่มอบหมาย',
    'Assignments:' => 'การมอบหมาย:',
    'At least 1 Hour before' => 'อย่างน้อย 1 ชั่วโมงก่อน',
    'At least 2 Hours before' => 'อย่างน้อย 2 ชั่วโมงก่อน',
    'Begin Task' => 'เริ่มงาน',
    'Checklist Items' => 'รายการตรวจสอบ',
    'Checklist:' => 'รายการตรวจสอบ:',
    'Close' => 'ปิด',
    'Color' => 'สี',
    'Completed' => 'เสร็จสมบูรณ์',
    'Continue Review' => 'ทบทวนต่อไป',
    'Create tasks' => 'สร้างงาน',
    'Created by me' => 'สร้างโดยผม',
    'Date' => 'วันที่',
    'Deadline at' => 'กำหนดเวลาที่',
    'Deadline: ' => 'วันกำหนดส่ง:',
    'Delete' => 'ลบ',
    'Delete list' => 'ลบรายการ',
    'Description' => 'คำอธิบาย',
    'Do not remind' => 'ไม่ต้องเตือน',
    'Do you really want to delete this task?' => 'คุณต้องการลบงานนี้หรือไม่?',
    'Don\'t add to calendar' => 'อย่าเพิ่มในปฏิทิน',
    'Drag entry' => 'ลากรายการ',
    'Edit' => 'แก้ไข',
    'Edit item (empty field will be removed)...' => 'แก้ไขรายการ (ช่องที่ว่างจะถูกลบออก)...',
    'Edit list' => 'แก้ไขรายการ',
    'End' => 'จบ',
    'End Date' => 'วันที่สิ้นสุด',
    'End Time' => 'เวลาสิ้นสุด',
    'End date' => 'วันที่สิ้นสุด',
    'End time must be after start time!' => 'เวลาสิ้นสุดต้องอยู่หลังเวลาเริ่มต้น',
    'Extend deadline request' => 'ขยายเวลาคำขอ',
    'Filter' => 'กรอง',
    'Filter tasks' => 'งานกรอง',
    'Finish Task' => 'เสร็จสิ้นภารกิจ',
    'General' => 'ทั่วไป',
    'General Settings' => 'การตั้งค่าทั่วไป',
    'Hide this list once all tasks are completed' => 'ซ่อนรายการนี้เมื่องานทั้งหมดเสร็จสิ้น',
    'I\'m assigned' => 'ฉันได้รับมอบหมาย',
    'I\'m responsible' => 'ฉันรับผิดชอบ',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'หากไม่ได้เลือกผู้ใช้ที่ได้รับมอบหมาย สมาชิก Space ทุกคนที่มีสิทธิ์ประมวลผลงานที่ไม่ได้รับมอบหมายสามารถประมวลผลงานได้',
    'In Progress' => 'กำลังดำเนินการ',
    'In Review' => 'อยู่ในรีวิว',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'ในกรณีที่ตัวเลือกการตรวจสอบทำงานอยู่ <strong>ผู้ใช้ที่รับผิดชอบ</strong> จะต้องตรวจสอบและปฏิเสธหรือยืนยันงานนี้ก่อนที่จะเสร็จสิ้น',
    'Invalid task list selection.' => 'การเลือกรายการงานไม่ถูกต้อง',
    'Let Task Review' => 'ให้งานตรวจสอบ',
    'Manage tasks' => 'จัดการงาน',
    'No Scheduling set for this Task' => 'ไม่ได้กำหนดตารางเวลาสำหรับงานนี้',
    'No pending tasks found' => 'ไม่พบงานที่ค้างอยู่',
    'No results found for the given filter.' => 'ไม่พบผลลัพธ์สำหรับตัวกรองที่ระบุ',
    'Open Task' => 'เปิดงาน',
    'Other Tasks' => 'งานอื่นๆ',
    'Overdue' => 'ค้างชำระ',
    'Overview' => 'ภาพรวม',
    'Parent Task' => 'งานผู้ปกครอง',
    'Pending' => 'รอดำเนินการ',
    'Pending Review' => 'รอการตรวจสอบ',
    'Process unassigned tasks' => 'ประมวลผลงานที่ไม่ได้รับมอบหมาย',
    'Ready For Review' => 'พร้อมสำหรับการตรวจสอบ',
    'Receive Notifications for Task Reminder.' => 'รับการแจ้งเตือนสำหรับตัวเตือนงาน',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'รับการแจ้งเตือนสำหรับงาน (การอัปเดตกำหนดเวลา การเปลี่ยนแปลงสถานะ ...)',
    'Reject Task' => 'ปฏิเสธงาน',
    'Remind Mode' => 'โหมดเตือนความจำ',
    'Reminder' => 'เตือนความจำ',
    'Reminder sent' => 'ส่งการช่วยเตือนแล้ว',
    'Reminders' => 'เตือนความจำ',
    'Request extension' => 'ขอขยายเวลา',
    'Request sent' => 'ส่งคำร้อง',
    'Reset Task' => 'รีเซ็ตงาน',
    'Responsible' => 'รับผิดชอบ',
    'Review by responsible user required' => 'ต้องตรวจสอบโดยผู้ใช้ที่รับผิดชอบ',
    'Scheduling' => 'การจัดตารางเวลา',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'เรียงลำดับ',
    'Sort order' => 'เรียงลำดับ',
    'Spaces' => 'ช่องว่าง',
    'Start' => 'เริ่ม',
    'Start Date' => 'วันที่เริ่มต้น',
    'Start Time' => 'เวลาเริ่มต้น',
    'Start date' => 'วันที่เริ่มต้น',
    'Starting at' => 'เริ่มต้นที่',
    'Status' => 'สถานะ',
    'Task' => 'งาน',
    'Task Users have been notified' => 'ผู้ใช้งานได้รับแจ้ง',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'งาน {task} ในอวกาศ {spaceName} สิ้นสุดที่ {dateTime}',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'งาน {task} ในอวกาศ {spaceName} เริ่มที่ {dateTime}',
    'Tasks' => 'งาน',
    'Tasks: Reminder' => 'งาน: เตือนความจำ',
    'This task can only be processed by assigned and responsible users.' => 'งานนี้สามารถดำเนินการได้โดยผู้ใช้ที่ได้รับมอบหมายและรับผิดชอบเท่านั้น',
    'This task requires to be reviewed by a responsible' => 'งานนี้ต้องได้รับการตรวจสอบโดยผู้รับผิดชอบ',
    'Time Zone' => 'เขตเวลา',
    'Title' => 'หัวข้อ',
    'Title and Color' => 'ชื่อเรื่องและสี',
    'Title of your task list' => 'ชื่อรายการงานของคุณ',
    'Today' => 'วันนี้',
    'Unsorted' => 'ไม่เรียงลำดับเรียงลำดับ',
    'View Online' => 'ดูออนไลน์',
    'You are assigned!' => 'คุณได้รับมอบหมาย!',
    'You are responsible!' => 'คุณมีความรับผิดชอบ!',
    'You have insufficient permissions to perform that operation!' => 'คุณมีสิทธิ์ไม่เพียงพอที่จะดำเนินการดังกล่าว',
    'Your Reminder for task {task}' => 'การแจ้งเตือนสำหรับงานของคุณ {task}',
    'ending Review' => 'สิ้นสุดการทบทวน',
    'view all' => 'ดูทั้งหมด',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} เหลือ',
    '{displayName} is assigned to this task' => '{displayName} ถูกกำหนดให้กับงานนี้',
    '{displayName} is responsible for this task' => '{displayName} รับผิดชอบงานนี้',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} มอบหมายให้คุณเป็นผู้รับผิดชอบในงาน {task} จากอวกาศ {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} มอบหมายให้คุณทำงาน {task} ในอวกาศ {spaceName}',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} เสร็จสิ้นภารกิจ {task} ในช่องว่าง {spaceName}',
    '{userName} completed task {task}.' => '{userName} เสร็จสิ้นภารกิจ {task}',
    '{userName} finished task {task}.' => '{userName} เสร็จสิ้นภารกิจ {task}',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ได้เปลี่ยนกำหนดเวลาสำหรับงาน {task} ใน space {spaceName}',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ได้เปิดงาน {task} อีกครั้งในช่องว่าง {spaceName}',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ได้ปฏิเสธงาน {task} ในช่องว่าง {spaceName} ว่าไม่สมบูรณ์',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} ทำเครื่องหมายงาน {task} ในช่องว่าง {spaceName} ว่าเสร็จแล้ว',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} ขอขยายกำหนดเวลาสำหรับงาน {task} ใน space {spaceName}',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} ขอให้คุณตรวจสอบงาน {task} ในช่องว่าง {spaceName}',
    '{userName} reset task {task}.' => '{userName} รีเซ็ตงาน {task}',
    '{userName} reviewed task {task}.' => '{userName} ตรวจทานงานแล้ว {task}',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} เริ่มทำงานกับงาน {task} ในอวกาศ {spaceName}',
    '{userName} works on task {task}.' => '{userName} ทำงาน {task}',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task List' => '',
    'Task content ID' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/th/base.php <==
<?php

return [
    '1 Day before' => '1 วันก่อน',
    '1 Month before' => '1 เดือนก่อน',
    '1 Week before' => '1 สัปดาห์ก่อน',
    '2 Days before' => '2 วันก่อน',
    '2 Weeks before' => '2 สัปดาห์ก่อน',
    '3 Weeks before' => '3 สัปดาห์ก่อน',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>ผู้ใช้ที่ได้รับมอบหมาย</strong> ได้รับอนุญาตให้ดำเนินการงานนี้',
    '<strong>Confirm</strong> task deletion' => '<strong>ยืนยัน</strong> การลบงาน',
    '<strong>Create</strong> task list' => '<strong>สร้าง</strong> รายการงาน',
    '<strong>Edit</strong> task' => '<strong>แก้ไข</strong> งาน',
    '<strong>Edit</strong> task list' => '<strong>แก้ไข</strong> รายการงาน',
    '<strong>Task</strong> Overview' => '<strong>งาน</strong> ภาพรวม',
    '<strong>Your</strong> tasks' => 'งาน <strong>ของคุณ</strong>',
    'Accept Task' => 'รับงาน',
    'Add Deadline to space calendar' => 'เพิ่มกำหนดเวลาในปฏิทินอวกาศ',
    'Add checkpoint...' => 'เพิ่มด่าน...',
    'Add reminder' => 'เพิ่มการเตือนความจำ',
    'Add responsible users' => 'เพิ่มผู้ใช้ที่รับผิดชอบ',
    'Add schedule to the space calendar' => 'เพิ่มกำหนดการในปฏิทินอวกาศ',
    'Add task' => 'เพิ่มงาน',
    'Add to space calendar' => 'เพิ่มในปฏิทินอวกาศ',
    'All Day' => 'ทั้งวัน',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'อนุญาตให้ผู้ใช้สร้างงานใหม่ ผู้ใช้จะสามารถแก้ไขและลบงานของตัวเองเท่านั้น',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'อนุญาตให้ผู้ใช้สร้าง ลบ และแก้ไขงานและรายการ และยังจัดเรียงงานและรายการ',
    'Allows the user to process unassigned tasks' => 'อนุญาตให้ผู้ใช้ประมวลผลงานที่ยังไม่ได้มอบหมาย',
    'Already requested' => 'ร้องขอแล้ว',
    'Assign users' => 'กำหนดผู้ใช้',
    'Assignment' => 'งานที่มอบหมาย',
    'At least 1 Hour before' => 'อย่างน้อย 1 ชั่วโมงก่อน',
    'At least 2 Hours before' => 'อย่างน้อย 2 ชั่วโมงก่อน',
    'Begin Task' => 'เริ่มงาน',
    'Checklist Items' => 'รายการตรวจสอบ',
    'Checklist:' => 'รายการตรวจสอบ:',
    'Close' => 'ปิด',
    'Color' => 'สี',
    'Completed' => 'เสร็จสมบูรณ์',
    'Continue Review' => 'ทบทวนต่อไป',
    'Create tasks' => 'สร้างงาน',
    'Created by me' => 'สร้างโดยผม',
    'Date' => 'วันที่',
    'Deadline: ' => 'วันกำหนดส่ง:',
    'Delete' => 'ลบ',
    'Delete list' => 'ลบรายการ',
    'Description' => 'คำอธิบาย',
    'Do not remind' => 'ไม่ต้องเตือน',
    'Do you really want to delete this task?' => 'คุณต้องการลบงานนี้หรือไม่?',
    'Don\'t add to calendar' => 'อย่าเพิ่มในปฏิทิน',
    'Edit' => 'แก้ไข',
    'Edit item (empty field will be removed)...' => 'แก้ไขรายการ (ช่องที่ว่างจะถูกลบออก)...',
    'Edit list' => 'แก้ไขรายการ',
    'End' => 'จบ',
    'End Date' => 'วันที่สิ้นสุด',
    'End Time' => 'เวลาสิ้นสุด',
    'End date' => 'วันที่สิ้นสุด',
    'End time must be after start time!' => 'เวลาสิ้นสุดต้องอยู่หลังเวลาเริ่มต้น',
    'Extend deadline request' => 'ขยายเวลาคำขอ',
    'Filter' => 'กรอง',
    'Filter tasks' => 'งานกรอง',
    'Finish Task' => 'เสร็จสิ้นภารกิจ',
    'General' => 'ทั่วไป',
    'General Settings' => 'การตั้งค่าทั่วไป',
    'Hide this list once all tasks are completed' => 'ซ่อนรายการนี้เมื่องานทั้งหมดเสร็จสิ้น',
    'I\'m assigned' => 'ฉันได้รับมอบหมาย',
    'I\'m responsible' => 'ฉันรับผิดชอบ',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'หากไม่ได้เลือกผู้ใช้ที่ได้รับมอบหมาย สมาชิก Space ทุกคนที่มีสิทธิ์ประมวลผลงานที่ไม่ได้รับมอบหมายสามารถประมวลผลงานได้',
    'In Progress' => 'กำลังดำเนินการ',
    'In Review' => 'อยู่ในรีวิว',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'ในกรณีที่ตัวเลือกการตรวจสอบทำงานอยู่ <strong>ผู้ใช้ที่รับผิดชอบ</strong> จะต้องตรวจสอบและปฏิเสธหรือยืนยันงานนี้ก่อนที่จะเสร็จสิ้น',
    'Invalid task list selection.' => 'การเลือกรายการงานไม่ถูกต้อง',
    'Let Task Review' => 'ให้งานตรวจสอบ',
    'Manage tasks' => 'จัดการงาน',
    'No Scheduling set for this Task' => 'ไม่ได้กำหนดตารางเวลาสำหรับงานนี้',
    'No pending tasks found' => 'ไม่พบงานที่ค้างอยู่',
    'No results found for the given filter.' => 'ไม่พบผลลัพธ์สำหรับตัวกรองที่ระบุ',
    'Open Task' => 'เปิดงาน',
    'Other Tasks' => 'งานอื่นๆ',
    'Overdue' => 'ค้างชำระ',
    'Overview' => 'ภาพรวม',
    'Parent Task' => 'งานผู้ปกครอง',
    'Pending' => 'รอดำเนินการ',
    'Pending Review' => 'รอการตรวจสอบ',
    'Process unassigned tasks' => 'ประมวลผลงานที่ไม่ได้รับมอบหมาย',
    'Ready For Review' => 'พร้อมสำหรับการตรวจสอบ',
    'Receive Notifications for Task Reminder.' => 'รับการแจ้งเตือนสำหรับตัวเตือนงาน',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'รับการแจ้งเตือนสำหรับงาน (การอัปเดตกำหนดเวลา การเปลี่ยนแปลงสถานะ ...)',
    'Reject Task' => 'ปฏิเสธงาน',
    'Remind Mode' => 'โหมดเตือนความจำ',
    'Reminder' => 'เตือนความจำ',
    'Reminder sent' => 'ส่งการช่วยเตือนแล้ว',
    'Reminders' => 'เตือนความจำ',
    'Request extension' => 'ขอขยายเวลา',
    'Request sent' => 'ส่งคำร้อง',
    'Reset Task' => 'รีเซ็ตงาน',
    'Responsible' => 'รับผิดชอบ',
    'Review by responsible user required' => 'ต้องตรวจสอบโดยผู้ใช้ที่รับผิดชอบ',
    'Scheduling' => 'การจัดตารางเวลา',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'เรียงลำดับ',
    'Sort order' => 'เรียงลำดับ',
    'Spaces' => 'ช่องว่าง',
    'Start' => 'เริ่ม',
    'Start Date' => 'วันที่เริ่มต้น',
    'Start Time' => 'เวลาเริ่มต้น',
    'Start date' => 'วันที่เริ่มต้น',
    'Starting at' => 'เริ่มต้นที่',
    'Status' => 'สถานะ',
    'Task' => 'งาน',
    'Task Users have been notified' => 'ผู้ใช้งานได้รับแจ้ง',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'งาน {task} ในอวกาศ {spaceName} สิ้นสุดที่ {dateTime}',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'งาน {task} ในอวกาศ {spaceName} เริ่มที่ {dateTime}',
    'Tasks' => 'งาน',
    'Tasks: Reminder' => 'งาน: เตือนความจำ',
    'This task requires to be reviewed by a responsible' => 'งานนี้ต้องได้รับการตรวจสอบโดยผู้รับผิดชอบ',
    'Time Zone' => 'เขตเวลา',
    'Title' => 'หัวข้อ',
    'Title and Color' => 'ชื่อเรื่องและสี',
    'Title of your task list' => 'ชื่อรายการงานของคุณ',
    'Today' => 'วันนี้',
    'Unsorted' => 'ไม่เรียงลำดับเรียงลำดับ',
    'View Online' => 'ดูออนไลน์',
    'You have insufficient permissions to perform that operation!' => 'คุณมีสิทธิ์ไม่เพียงพอที่จะดำเนินการดังกล่าว',
    'Your Reminder for task {task}' => 'การแจ้งเตือนสำหรับงานของคุณ {task}',
    'view all' => 'ดูทั้งหมด',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} เหลือ',
    '{displayName} is assigned to this task' => '{displayName} ถูกกำหนดให้กับงานนี้',
    '{displayName} is responsible for this task' => '{displayName} รับผิดชอบงานนี้',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} มอบหมายให้คุณเป็นผู้รับผิดชอบในงาน {task} จากอวกาศ {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} มอบหมายให้คุณทำงาน {task} ในอวกาศ {spaceName}',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} เสร็จสิ้นภารกิจ {task} ในช่องว่าง {spaceName}',
    '{userName} completed task {task}.' => '{userName} เสร็จสิ้นภารกิจ {task}',
    '{userName} finished task {task}.' => '{userName} เสร็จสิ้นภารกิจ {task}',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ได้เปลี่ยนกำหนดเวลาสำหรับงาน {task} ใน space {spaceName}',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ได้เปิดงาน {task} อีกครั้งในช่องว่าง {spaceName}',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ได้ปฏิเสธงาน {task} ในช่องว่าง {spaceName} ว่าไม่สมบูรณ์',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} ทำเครื่องหมายงาน {task} ในช่องว่าง {spaceName} ว่าเสร็จแล้ว',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} ขอขยายกำหนดเวลาสำหรับงาน {task} ใน space {spaceName}',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} ขอให้คุณตรวจสอบงาน {task} ในช่องว่าง {spaceName}',
    '{userName} reset task {task}.' => '{userName} รีเซ็ตงาน {task}',
    '{userName} reviewed task {task}.' => '{userName} ตรวจทานงานแล้ว {task}',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} เริ่มทำงานกับงาน {task} ในอวกาศ {spaceName}',
    '{userName} works on task {task}.' => '{userName} ทำงาน {task}',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignments' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Request Review' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task List' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
